@@ -1,4 +1,4 @@
-import requests
+import requests, time
 from python_helper import Constant as c
 from python_helper import ReflectionHelper, ObjectHelper, log, Function, StringHelper
 from python_framework import (
@@ -191,6 +191,9 @@ def MessageEmitterMethod(
             **kwargs
         ):
             verb = HttpDomain.Verb.POST
+            print(f'logRequest: {logRequest}')
+            print(f'resourceMethodConfig.wrapperManager.resourceInstance.logRequest: {resourceMethodConfig.wrapperManager.resourceInstance.logRequest}, resourceMethodConfig.wrapperManager.logRequest: {resourceMethodConfig.wrapperManager.logRequest}')
+            print(f'resourceMethodConfig.wrapperManager.shouldLogRequest(): {resourceMethodConfig.wrapperManager.shouldLogRequest()}')
             url, params, headers, body, timeout, logRequest = ClientUtil.parseParameters(
                 resourceInstance,
                 resourceMethodConfig,
@@ -199,7 +202,7 @@ def MessageEmitterMethod(
                 headers,
                 Serializer.getObjectAsDictionary(
                     MessageDto.MessageRequestDto(
-                        key = ConverterStatic.getValueOrDefault(messageKey, Serializer.newUuid()),
+                        key = messageKey,
                         queueKey = queueKey,
                         groupKey = groupKey,
                         content = body
@@ -245,7 +248,10 @@ def MessageEmitterMethod(
             httpClientResolversMap = HTTP_CLIENT_RESOLVERS_MAP
             resourceMethodGroupKey = None if MessageConstant.GROUP_KEY_CLIENT_ATTRIBUTE_NAME not in kwargs else kwargs.pop(MessageConstant.GROUP_KEY_CLIENT_ATTRIBUTE_NAME)
             resourceMethodMessageKey = None if MessageConstant.MESSAGE_KEY_CLIENT_ATTRIBUTE_NAME not in kwargs else kwargs.pop(MessageConstant.MESSAGE_KEY_CLIENT_ATTRIBUTE_NAME)
-            key = ConverterStatic.getValueOrDefault(resourceMethodMessageKey, Serializer.newUuid())
+            if ObjectHelper.isNone(resourceMethodMessageKey):
+                key = f'{f"{time.time():0<10}".replace(c.DOT, c.DASH)}{c.DASH}{Serializer.newUuid()}'
+            else:
+                key
             messageCreationRequest = MessageDto.MessageCreationRequestDto(
                 key = key,
                 queueKey = resourceMethodQueueKey,
